0.9.9 API documentation: mixed_product.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

mixed_product.hpp
Go to the documentation of this file.
1
13 #pragma once
14
15 // Dependency:
16 #include "../glm.hpp"
17
18 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
19 # ifndef GLM_ENABLE_EXPERIMENTAL
20 # pragma message("GLM: GLM_GTX_mixed_product is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
21 # else
22 # pragma message("GLM: GLM_GTX_mixed_product extension included")
23 # endif
24 #endif
25
26 namespace glm
27 {
30
32 template<typename T, qualifier Q>
33 GLM_FUNC_DECL T mixedProduct(
34 vec<3, T, Q> const& v1,
35 vec<3, T, Q> const& v2,
36 vec<3, T, Q> const& v3);
37
39 }// namespace glm
40
41 #include "mixed_product.inl"
glm::mixedProduct
GLM_FUNC_DECL T mixedProduct(vec< 3, T, Q > const &v1, vec< 3, T, Q > const &v2, vec< 3, T, Q > const &v3)
Mixed product of 3 vectors (from GLM_GTX_mixed_product extension)
glm
Definition: common.hpp:20